# Credits

## Development Lead

  - Jakub Semik \<<kuba.semik@gmail.com>\>

## Contributors

| Full Name | GitHub |
| ------ | ------ |
| Davit Tovmasyan | [@davitovmasyan]( https://github.com/davitovmasyan ) |
| Sergei Maertens | [@sergei-maertens]( https://github.com/sergei-maertens ) |
| 李琼羽 | [@w392807287]( https://github.com/w392807287 ) |
| Usman Hussain | [@usmandap]( https://github.com/usmandap ) |
| paterit | [@paterit]( https://github.com/paterit ) |
| Jules Robichaud-Gagnon | [@jrobichaud]( https://github.com/jrobichaud ) |
| Dustin Martin | [@dmartin]( https://github.com/dmartin ) |
| Davit Tovmasyan | [@davitovmasyan]( https://github.com/davitovmasyan ) |
| Swojak-A | [@Swojak-A]( https://github.com/Swojak-A ) |
| Álvaro Mondéjar | [@mondeja]( https://github.com/mondeja ) |
